<?php

namespace Drupal\gtfs\Plugin\rest\resource;

/**
 * Class ResourceMeta
 *
 * Utility class for generating default HATEOAS metadata for GTFS entities.
 *
 * @package Drupal\gtfs\Plugin\rest\resource
 */
class ResourceMeta {

  public static $default_metadata = [
    'totalCount' => 0,
    'dataCount' => 0,
    'links' => [
      'next' => false,
      'previous' => false
    ],
    'limit' => 0,
    'offset' => 0,
  ];


  /**
   * Instantiates metadata.
   *
   * @param array $metadata
   *
   * @return array
   */
  public static function create(array $metadata): array {
    return array_merge(self::$default_metadata, $metadata);
  }


  /**
   * Alters {@see $metadata} based on the results generated by a query.
   *
   * @param array $metadata
   * @param $parameters
   */
  public static function setPagerFromResults(array &$metadata, $parameters) {
    if(!isset($parameters['results'])) return;
    if(!isset($parameters['url'])) return;

    $dataCount = count($parameters['results']);

    $metadata['dataCount'] = $dataCount;

    if($metadata['totalCount'] > $metadata['offset'] + $dataCount) {
      $metadata['links']['next'] = \Drupal::request()->getSchemeAndHttpHost() . $parameters['url'] . '?' . http_build_query([
        'offset' => $metadata['offset'] + $metadata['limit'],
        'limit' => $metadata['limit']
      ]);
    }

    if($metadata['offset']) {
      $metadata['links']['previous'] = \Drupal::request()->getSchemeAndHttpHost() . $parameters['url'] . '?' . http_build_query([
        'offset' => min(0, $metadata['offset'] - $metadata['limit']),
        'limit' => $metadata['limit']
      ]);
    }
  }
}
